@@ -24,14 +24,14 @@ var SortGroup = {
 var CtrlAltTabManager = new Lang.Class({
     Name: 'CtrlAltTabManager',
 
-    _init: function() {
+    _init() {
         this._items = [];
         this.addGroup(global.window_group, _("Windows"),
                       'focus-windows-symbolic', { sortGroup: SortGroup.TOP,
-                                                  focusCallback: Lang.bind(this, this._focusWindows) });
+                                                  focusCallback: this._focusWindows.bind(this) });
     },
 
-    addGroup: function(root, name, icon, params) {
+    addGroup(root, name, icon, params) {
         let item = Params.parse(params, { sortGroup: SortGroup.MIDDLE,
                                           proxy: root,
                                           focusCallback: null });
@@ -41,12 +41,12 @@ var CtrlAltTabManager = new Lang.Class({
         item.iconName = icon;
 
         this._items.push(item);
-        root.connect('destroy', Lang.bind(this, function() { this.removeGroup(root); }));
+        root.connect('destroy', () => { this.removeGroup(root); });
         if (root instanceof St.Widget)
             global.focus_manager.add_group(root);
     },
 
-    removeGroup: function(root) {
+    removeGroup(root) {
         if (root instanceof St.Widget)
             global.focus_manager.remove_group(root);
         for (let i = 0; i < this._items.length; i++) {
@@ -57,7 +57,7 @@ var CtrlAltTabManager = new Lang.Class({
         }
     },
 
-    focusGroup: function(item, timestamp) {
+    focusGroup(item, timestamp) {
         if (item.focusCallback)
             item.focusCallback(timestamp);
         else
@@ -68,7 +68,7 @@ var CtrlAltTabManager = new Lang.Class({
     // and everything else in between, sorted by X coordinate, so that
     // they will have the same left-to-right ordering in the
     // Ctrl-Alt-Tab dialog as they do onscreen.
-    _sortItems: function(a, b) {
+    _sortItems(a, b) {
         if (a.sortGroup != b.sortGroup)
             return a.sortGroup - b.sortGroup;
 
@@ -79,15 +79,17 @@ var CtrlAltTabManager = new Lang.Class({
         return ax - bx;
     },
 
-    popup: function(backward, binding, mask) {
+    popup(backward, binding, mask) {
         // Start with the set of focus groups that are currently mapped
-        let items = this._items.filter(function (item) { return item.proxy.mapped; });
+        let items = this._items.filter(item => item.proxy.mapped);
 
         // And add the windows metacity would show in its Ctrl-Alt-Tab list
         if (Main.sessionMode.hasWindows && !Main.overview.visible) {
-            let screen = global.screen;
-            let display = screen.get_display();
-            let windows = display.get_tab_list(Meta.TabList.DOCKS, screen.get_active_workspace ());
+            let display = global.display;
+            let workspaceManager = global.workspace_manager;
+            let activeWorkspace = workspaceManager.get_active_workspace();
+            let windows = display.get_tab_list(Meta.TabList.DOCKS,
+                                               activeWorkspace);
             let windowTracker = Shell.WindowTracker.get_default();
             let textureCache = St.TextureCache.get_default();
             for (let i = 0; i < windows.length; i++) {
@@ -105,10 +107,9 @@ var CtrlAltTabManager = new Lang.Class({
 
                 items.push({ name: windows[i].title,
                              proxy: windows[i].get_compositor_private(),
-                             focusCallback: Lang.bind(windows[i],
-                                 function(timestamp) {
-                                     Main.activateWindow(this, timestamp);
-                                 }),
+                             focusCallback: function(timestamp) {
+                                 Main.activateWindow(this, timestamp);
+                             }.bind(windows[i]),
                              iconActor: icon,
                              iconName: iconName,
                              sortGroup: SortGroup.MIDDLE });
@@ -118,21 +119,21 @@ var CtrlAltTabManager = new Lang.Class({
         if (!items.length)
             return;
 
-        items.sort(Lang.bind(this, this._sortItems));
+        items.sort(this._sortItems.bind(this));
 
         if (!this._popup) {
             this._popup = new CtrlAltTabPopup(items);
             this._popup.show(backward, binding, mask);
 
             this._popup.actor.connect('destroy',
-                                      Lang.bind(this, function() {
+                                      () => {
                                           this._popup = null;
-                                      }));
+                                      });
         }
     },
 
-    _focusWindows: function(timestamp) {
-        global.screen.focus_default_window(timestamp);
+    _focusWindows(timestamp) {
+        global.display.focus_default_window(timestamp);
     }
 });
 
@@ -140,13 +141,13 @@ var CtrlAltTabPopup = new Lang.Class({
     Name: 'CtrlAltTabPopup',
     Extends: SwitcherPopup.SwitcherPopup,
 
-    _init: function(items) {
+    _init(items) {
         this.parent(items);
 
         this._switcherList = new CtrlAltTabSwitcher(this._items);
     },
 
-    _keyPressHandler: function(keysym, action) {
+    _keyPressHandler(keysym, action) {
         if (action == Meta.KeyBindingAction.SWITCH_PANELS)
             this._select(this._next());
         else if (action == Meta.KeyBindingAction.SWITCH_PANELS_BACKWARD)
@@ -161,7 +162,7 @@ var CtrlAltTabPopup = new Lang.Class({
         return Clutter.EVENT_STOP;
     },
 
-    _finish : function(time) {
+    _finish(time) {
         this.parent(time);
         Main.ctrlAltTabManager.focusGroup(this._items[this._selectedIndex], time);
     },
@@ -171,14 +172,14 @@ var CtrlAltTabSwitcher = new Lang.Class({
     Name: 'CtrlAltTabSwitcher',
     Extends: SwitcherPopup.SwitcherList,
 
-    _init : function(items) {
+    _init(items) {
         this.parent(true);
 
         for (let i = 0; i < items.length; i++)
             this._addIcon(items[i]);
     },
 
-    _addIcon : function(item) {
+    _addIcon(item) {
         let box = new St.BoxLayout({ style_class: 'alt-tab-app',
                                      vertical: true });
 
